CACHE                                    = 0
POP_TOP                                  = 1
PUSH_NULL                                = 2
INTERPRETER_EXIT                         = 3
END_FOR                                  = 4
END_SEND                                 = 5
NOP                                      = 9
UNARY_NEGATIVE                          = 11
UNARY_NOT                               = 12
UNARY_INVERT                            = 15
RESERVED                                = 17
BINARY_SUBSCR                           = 25
BINARY_SLICE                            = 26
STORE_SLICE                             = 27
GET_LEN                                 = 30
MATCH_MAPPING                           = 31
MATCH_SEQUENCE                          = 32
MATCH_KEYS                              = 33
PUSH_EXC_INFO                           = 35
CHECK_EXC_MATCH                         = 36
CHECK_EG_MATCH                          = 37
WITH_EXCEPT_START                       = 49
GET_AITER                               = 50
GET_ANEXT                               = 51
BEFORE_ASYNC_WITH                       = 52
BEFORE_WITH                             = 53
END_ASYNC_FOR                           = 54
CLEANUP_THROW                           = 55
STORE_SUBSCR                            = 60
DELETE_SUBSCR                           = 61
GET_ITER                                = 68
GET_YIELD_FROM_ITER                     = 69
LOAD_BUILD_CLASS                        = 71
LOAD_ASSERTION_ERROR                    = 74
RETURN_GENERATOR                        = 75
RETURN_VALUE                            = 83
SETUP_ANNOTATIONS                       = 85
LOAD_LOCALS                             = 87
POP_EXCEPT                              = 89
HAVE_ARGUMENT                           = 90
STORE_NAME                              = 90
DELETE_NAME                             = 91
UNPACK_SEQUENCE                         = 92
FOR_ITER                                = 93
UNPACK_EX                               = 94
STORE_ATTR                              = 95
DELETE_ATTR                             = 96
STORE_GLOBAL                            = 97
DELETE_GLOBAL                           = 98
SWAP                                    = 99
LOAD_CONST                             = 100
LOAD_NAME                              = 101
BUILD_TUPLE                            = 102
BUILD_LIST                             = 103
BUILD_SET                              = 104
BUILD_MAP                              = 105
LOAD_ATTR                              = 106
COMPARE_OP                             = 107
IMPORT_NAME                            = 108
IMPORT_FROM                            = 109
JUMP_FORWARD                           = 110
POP_JUMP_IF_FALSE                      = 114
POP_JUMP_IF_TRUE                       = 115
LOAD_GLOBAL                            = 116
IS_OP                                  = 117
CONTAINS_OP                            = 118
RERAISE                                = 119
COPY                                   = 120
RETURN_CONST                           = 121
BINARY_OP                              = 122
SEND                                   = 123
LOAD_FAST                              = 124
STORE_FAST                             = 125
DELETE_FAST                            = 126
LOAD_FAST_CHECK                        = 127
POP_JUMP_IF_NOT_NONE                   = 128
POP_JUMP_IF_NONE                       = 129
RAISE_VARARGS                          = 130
GET_AWAITABLE                          = 131
MAKE_FUNCTION                          = 132
BUILD_SLICE                            = 133
JUMP_BACKWARD_NO_INTERRUPT             = 134
MAKE_CELL                              = 135
LOAD_CLOSURE                           = 136
LOAD_DEREF                             = 137
STORE_DEREF                            = 138
DELETE_DEREF                           = 139
JUMP_BACKWARD                          = 140
LOAD_SUPER_ATTR                        = 141
CALL_FUNCTION_EX                       = 142
LOAD_FAST_AND_CLEAR                    = 143
EXTENDED_ARG                           = 144
LIST_APPEND                            = 145
SET_ADD                                = 146
MAP_ADD                                = 147
COPY_FREE_VARS                         = 149
YIELD_VALUE                            = 150
RESUME                                 = 151
MATCH_CLASS                            = 152
FORMAT_VALUE                           = 155
BUILD_CONST_KEY_MAP                    = 156
BUILD_STRING                           = 157
LIST_EXTEND                            = 162
SET_UPDATE                             = 163
DICT_MERGE                             = 164
DICT_UPDATE                            = 165
CALL                                   = 171
KW_NAMES                               = 172
CALL_INTRINSIC_1                       = 173
CALL_INTRINSIC_2                       = 174
LOAD_FROM_DICT_OR_GLOBALS              = 175
LOAD_FROM_DICT_OR_DEREF                = 176
MIN_INSTRUMENTED_OPCODE                = 237
INSTRUMENTED_LOAD_SUPER_ATTR           = 237
INSTRUMENTED_POP_JUMP_IF_NONE          = 238
INSTRUMENTED_POP_JUMP_IF_NOT_NONE      = 239
INSTRUMENTED_RESUME                    = 240
INSTRUMENTED_CALL                      = 241
INSTRUMENTED_RETURN_VALUE              = 242
INSTRUMENTED_YIELD_VALUE               = 243
INSTRUMENTED_CALL_FUNCTION_EX          = 244
INSTRUMENTED_JUMP_FORWARD              = 245
INSTRUMENTED_JUMP_BACKWARD             = 246
INSTRUMENTED_RETURN_CONST              = 247
INSTRUMENTED_FOR_ITER                  = 248
INSTRUMENTED_POP_JUMP_IF_FALSE         = 249
INSTRUMENTED_POP_JUMP_IF_TRUE          = 250
INSTRUMENTED_END_FOR                   = 251
INSTRUMENTED_END_SEND                  = 252
INSTRUMENTED_INSTRUCTION               = 253
INSTRUMENTED_LINE                      = 254
MIN_PSEUDO_OPCODE                      = 256
SETUP_FINALLY                          = 256
SETUP_CLEANUP                          = 257
SETUP_WITH                             = 258
POP_BLOCK                              = 259
JUMP                                   = 260
JUMP_NO_INTERRUPT                      = 261
LOAD_METHOD                            = 262
LOAD_SUPER_METHOD                      = 263
LOAD_ZERO_SUPER_METHOD                 = 264
LOAD_ZERO_SUPER_ATTR                   = 265
STORE_FAST_MAYBE_NULL                  = 266
MAX_PSEUDO_OPCODE                      = 266
BINARY_OP_ADD_FLOAT                      = 6
BINARY_OP_ADD_INT                        = 7
BINARY_OP_ADD_UNICODE                    = 8
BINARY_OP_INPLACE_ADD_UNICODE           = 10
BINARY_OP_MULTIPLY_FLOAT                = 13
BINARY_OP_MULTIPLY_INT                  = 14
BINARY_OP_SUBTRACT_FLOAT                = 16
BINARY_OP_SUBTRACT_INT                  = 18
BINARY_SUBSCR_DICT                      = 19
BINARY_SUBSCR_GETITEM                   = 20
BINARY_SUBSCR_LIST_INT                  = 21
BINARY_SUBSCR_TUPLE_INT                 = 22
CALL_PY_EXACT_ARGS                      = 23
CALL_PY_WITH_DEFAULTS                   = 24
CALL_BOUND_METHOD_EXACT_ARGS            = 28
CALL_BUILTIN_CLASS                      = 29
CALL_BUILTIN_FAST_WITH_KEYWORDS         = 34
CALL_METHOD_DESCRIPTOR_FAST_WITH_KEYWORDS  = 38
CALL_NO_KW_BUILTIN_FAST                 = 39
CALL_NO_KW_BUILTIN_O                    = 40
CALL_NO_KW_ISINSTANCE                   = 41
CALL_NO_KW_LEN                          = 42
CALL_NO_KW_LIST_APPEND                  = 43
CALL_NO_KW_METHOD_DESCRIPTOR_FAST       = 44
CALL_NO_KW_METHOD_DESCRIPTOR_NOARGS     = 45
CALL_NO_KW_METHOD_DESCRIPTOR_O          = 46
CALL_NO_KW_STR_1                        = 47
CALL_NO_KW_TUPLE_1                      = 48
CALL_NO_KW_TYPE_1                       = 56
COMPARE_OP_FLOAT                        = 57
COMPARE_OP_INT                          = 58
COMPARE_OP_STR                          = 59
FOR_ITER_LIST                           = 62
FOR_ITER_TUPLE                          = 63
FOR_ITER_RANGE                          = 64
FOR_ITER_GEN                            = 65
LOAD_SUPER_ATTR_ATTR                    = 66
LOAD_SUPER_ATTR_METHOD                  = 67
LOAD_ATTR_CLASS                         = 70
LOAD_ATTR_GETATTRIBUTE_OVERRIDDEN       = 72
LOAD_ATTR_INSTANCE_VALUE                = 73
LOAD_ATTR_MODULE                        = 76
LOAD_ATTR_PROPERTY                      = 77
LOAD_ATTR_SLOT                          = 78
LOAD_ATTR_WITH_HINT                     = 79
LOAD_ATTR_METHOD_LAZY_DICT              = 80
LOAD_ATTR_METHOD_NO_DICT                = 81
LOAD_ATTR_METHOD_WITH_VALUES            = 82
LOAD_CONST__LOAD_FAST                   = 84
LOAD_FAST__LOAD_CONST                   = 86
LOAD_FAST__LOAD_FAST                    = 88
LOAD_GLOBAL_BUILTIN                    = 111
LOAD_GLOBAL_MODULE                     = 112
STORE_ATTR_INSTANCE_VALUE              = 113
STORE_ATTR_SLOT                        = 148
STORE_ATTR_WITH_HINT                   = 153
STORE_FAST__LOAD_FAST                  = 154
STORE_FAST__STORE_FAST                 = 158
STORE_SUBSCR_DICT                      = 159
STORE_SUBSCR_LIST_INT                  = 160
UNPACK_SEQUENCE_LIST                   = 161
UNPACK_SEQUENCE_TUPLE                  = 166
UNPACK_SEQUENCE_TWO_TUPLE              = 167
SEND_GEN                               = 168


thing = {}
def outer():
    x = 1
    other_thing = thing
    def inner():
        other_thing = {}
        nonlocal x
        x += 1
        from builtins import print, max
        print(x,other_thing, 7+4)
        other_thing["hi"] = 77
        
        def thingy():
            other_thing["somethin"] = 11
            return 10
        global thing
        thing = thingy
        return thingy()
    return inner

inner = outer()
import dis
instructions = dis.get_instructions(inner)
instructions = tuple(instructions)
for each in instructions:
    print(each)

def is_pure(function, local_vars=None, local_functions=None):
    import dis
    instructions = dis.get_instructions(function)
    instructions = tuple(instructions)
    prev_prev_instruction = None
    prev_instruction = None
    local_vars = local_vars or set()
    local_functions = local_functions or {}
    for each in instructions:
        opcode = each.opcode
        if opcode == STORE_FAST or opcode == STORE_DEREF:
            local_vars.add(each.argrepr)
            if prev_instruction and prev_instruction.opcode == MAKE_FUNCTION and prev_prev_instruction and prev_prev_instruction.opcode == LOAD_CONST:
                local_functions[each.argrepr] = prev_prev_instruction.argval
                # should be code type
                is_pure(prev_instruction.argval, local_vars, local_functions)
                
                local_functions.add(prev_instruction)
        elif opcode == LOAD_GLOBAL:
            return False
        # nonlocal var
        elif (opcode == LOAD_FAST or opcode == LOAD_DEREF) and each.argrepr not in local_vars:
            return False
        prev_prev_instruction = prev_instruction
        prev_instruction = each
    return True
    
def inner():
    a1 = None
    a2 = None
    a3 = None
    a4 = None
    a5 = None
    a6 = None
    a7 = None
    a8 = None
    a9 = None
    a10 = None
    a11 = None
    a12 = None
    a13 = None
    a14 = None
    a15 = None
    a16 = None
    a17 = None
    a18 = None
    a19 = None
    a20 = None
    a21 = None
    a22 = None
    a23 = None
    a24 = None
    a25 = None
    a26 = None
    a27 = None
    a28 = None
    a29 = None
    a30 = None
    a31 = None
    a32 = None
    a33 = None
    a34 = None
    a35 = None
    a36 = None
    a37 = None
    a38 = None
    a39 = None
    a40 = None
    a41 = None
    a42 = None
    a43 = None
    a44 = None
    a45 = None
    a46 = None
    a47 = None
    a48 = None
    a49 = None
    a50 = None
    a51 = None
    a52 = None
    a53 = None
    a54 = None
    a55 = None
    a56 = None
    a57 = None
    a58 = None
    a59 = None
    a60 = None
    a61 = None
    a62 = None
    a63 = None
    a64 = None
    a65 = None
    a66 = None
    a67 = None
    a68 = None
    a69 = None
    a70 = None
    a71 = None
    a72 = None
    a73 = None
    a74 = None
    a75 = None
    a76 = None
    a77 = None
    a78 = None
    a79 = None
    a80 = None
    a81 = None
    a82 = None
    a83 = None
    a84 = None
    a85 = None
    a86 = None
    a87 = None
    a88 = None
    a89 = None
    a90 = None
    a91 = None
    a92 = None
    a93 = None
    a94 = None
    a95 = None
    a96 = None
    a97 = None
    a98 = None
    a99 = None
    a100 = None
    a101 = None
    a102 = None
    a103 = None
    a104 = None
    a105 = None
    a106 = None
    a107 = None
    a108 = None
    a109 = None
    a110 = None
    a111 = None
    a112 = None
    a113 = None
    a114 = None
    a115 = None
    a116 = None
    a117 = None
    a118 = None
    a119 = None
    a120 = None
    a121 = None
    a122 = None
    a123 = None
    a124 = None
    a125 = None
    a126 = None
    a127 = None
    a128 = None
    a129 = None
    a130 = None
    a131 = None
    a132 = None
    a133 = None
    a134 = None
    a135 = None
    a136 = None
    a137 = None
    a138 = None
    a139 = None
    a140 = None
    a141 = None
    a142 = None
    a143 = None
    a144 = None
    a145 = None
    a146 = None
    a147 = None
    a148 = None
    a149 = None
    a150 = None
    a151 = None
    a152 = None
    a153 = None
    a154 = None
    a155 = None
    a156 = None
    a157 = None
    a158 = None
    a159 = None
    a160 = None
    a161 = None
    a162 = None
    a163 = None
    a164 = None
    a165 = None
    a166 = None
    a167 = None
    a168 = None
    a169 = None
    a170 = None
    a171 = None
    a172 = None
    a173 = None
    a174 = None
    a175 = None
    a176 = None
    a177 = None
    a178 = None
    a179 = None
    a180 = None
    a181 = None
    a182 = None
    a183 = None
    a184 = None
    a185 = None
    a186 = None
    a187 = None
    a188 = None
    a189 = None
    a190 = None
    a191 = None
    a192 = None
    a193 = None
    a194 = None
    a195 = None
    a196 = None
    a197 = None
    a198 = None
    a199 = None
    a200 = None
    a201 = None
    a202 = None
    a203 = None
    a204 = None
    a205 = None
    a206 = None
    a207 = None
    a208 = None
    a209 = None
    a210 = None
    a211 = None
    a212 = None
    a213 = None
    a214 = None
    a215 = None
    a216 = None
    a217 = None
    a218 = None
    a219 = None
    a220 = None
    a221 = None
    a222 = None
    a223 = None
    a224 = None
    a225 = None
    a226 = None
    a227 = None
    a228 = None
    a229 = None
    a230 = None
    a231 = None
    a232 = None
    a233 = None
    a234 = None
    a235 = None
    a236 = None
    a237 = None
    a238 = None
    a239 = None
    a240 = None
    a241 = None
    a242 = None
    a243 = None
    a244 = None
    a245 = None
    a246 = None
    a247 = None
    a248 = None
    a249 = None
    a250 = None
    a251 = None
    a252 = None
    a253 = None
    a254 = None
    a255 = None
    a256 = None
    a257 = None
    a258 = None
    a259 = None
    a260 = None
    a261 = None
    a262 = None
    a263 = None
    a264 = None
    a265 = None
    a266 = None
    a267 = None
    a268 = None
    a269 = None
    a270 = None
    a271 = None
    a272 = None
    a273 = None
    a274 = None
    a275 = None
    a276 = None
    a277 = None
    a278 = None
    a279 = None
    a280 = None
    a281 = None
    a282 = None
    a283 = None
    a284 = None
    a285 = None
    a286 = None
    a287 = None
    a288 = None
    a289 = None
    a290 = None
    a291 = None
    a292 = None
    a293 = None
    a294 = None
    a295 = None
    a296 = None
    a297 = None
    a298 = None
    a299 = None
    a300 = None
    a301 = None
    a302 = None
    a303 = None
    a304 = None
    a305 = None
    a306 = None
    a307 = None
    a308 = None
    a309 = None
    a310 = None
    a311 = None
    a312 = None
    a313 = None
    a314 = None
    a315 = None
    a316 = None
    a317 = None
    a318 = None
    a319 = None
    a320 = None
    a321 = None
    a322 = None
    a323 = None
    a324 = None
    a325 = None
    a326 = None
    a327 = None
    a328 = None
    a329 = None
    a330 = None
    a331 = None
    a332 = None
    a333 = None
    a334 = None
    a335 = None
    a336 = None
    a337 = None
    a338 = None
    a339 = None
    a340 = None
    a341 = None
    a342 = None
    a343 = None
    a344 = None
    a345 = None
    a346 = None
    a347 = None
    a348 = None
    a349 = None
    a350 = None
    a351 = None
    a352 = None
    a353 = None
    a354 = None
    a355 = None
    a356 = None
    a357 = None
    a358 = None
    a359 = None
    a360 = None
    a361 = None
    a362 = None
    a363 = None
    a364 = None
    a365 = None
    a366 = None
    a367 = None
    a368 = None
    a369 = None
    a370 = None
    a371 = None
    a372 = None
    a373 = None
    a374 = None
    a375 = None
    a376 = None
    a377 = None
    a378 = None
    a379 = None
    a380 = None
    a381 = None
    a382 = None
    a383 = None
    a384 = None
    a385 = None
    a386 = None
    a387 = None
    a388 = None
    a389 = None
    a390 = None
    a391 = None
    a392 = None
    a393 = None
    a394 = None
    a395 = None
    a396 = None
    a397 = None
    a398 = None
    a399 = None
    a400 = None
    a401 = None
    a402 = None
    a403 = None
    a404 = None
    a405 = None
    a406 = None
    a407 = None
    a408 = None
    a409 = None
    a410 = None
    a411 = None
    a412 = None
    a413 = None
    a414 = None
    a415 = None
    a416 = None
    a417 = None
    a418 = None
    a419 = None
    a420 = None
    a421 = None
    a422 = None
    a423 = None
    a424 = None
    a425 = None
    a426 = None
    a427 = None
    a428 = None
    a429 = None
    a430 = None
    a431 = None
    a432 = None
    a433 = None
    a434 = None
    a435 = None
    a436 = None
    a437 = None
    a438 = None
    a439 = None
    a440 = None
    a441 = None
    a442 = None
    a443 = None
    a444 = None
    a445 = None
    a446 = None
    a447 = None
    a448 = None
    a449 = None
    a450 = None
    a451 = None
    a452 = None
    a453 = None
    a454 = None
    a455 = None
    a456 = None
    a457 = None
    a458 = None
    a459 = None
    a460 = None
    a461 = None
    a462 = None
    a463 = None
    a464 = None
    a465 = None
    a466 = None
    a467 = None
    a468 = None
    a469 = None
    a470 = None
    a471 = None
    a472 = None
    a473 = None
    a474 = None
    a475 = None
    a476 = None
    a477 = None
    a478 = None
    a479 = None
    a480 = None
    a481 = None
    a482 = None
    a483 = None
    a484 = None
    a485 = None
    a486 = None
    a487 = None
    a488 = None
    a489 = None
    a490 = None
    a491 = None
    a492 = None
    a493 = None
    a494 = None
    a495 = None
    a496 = None
    a497 = None
    a498 = None
    a499 = None
    a500 = None
    a501 = None
    a502 = None
    a503 = None
    a504 = None
    a505 = None
    a506 = None
    a507 = None
    a508 = None
    a509 = None
    a510 = None
    a511 = None
    a512 = None
    a513 = None
    a514 = None
    a515 = None
    a516 = None
    a517 = None
    a518 = None
    a519 = None
    a520 = None
    a521 = None
    a522 = None
    a523 = None
    a524 = None
    a525 = None
    a526 = None
    a527 = None
    a528 = None
    a529 = None
    a530 = None
    a531 = None
    a532 = None
    a533 = None
    a534 = None
    a535 = None
    a536 = None
    a537 = None
    a538 = None
    a539 = None
    a540 = None
    a541 = None
    a542 = None
    a543 = None
    a544 = None
    a545 = None
    a546 = None
    a547 = None
    a548 = None
    a549 = None
    a550 = None
    a551 = None
    a552 = None
    a553 = None
    a554 = None
    a555 = None
    a556 = None
    a557 = None
    a558 = None
    a559 = None
    a560 = None
    a561 = None
    a562 = None
    a563 = None
    a564 = None
    a565 = None
    a566 = None
    a567 = None
    a568 = None
    a569 = None
    a570 = None
    a571 = None
    a572 = None
    a573 = None
    a574 = None
    a575 = None
    a576 = None
    a577 = None
    a578 = None
    a579 = None
    a580 = None
    a581 = None
    a582 = None
    a583 = None
    a584 = None
    a585 = None
    a586 = None
    a587 = None
    a588 = None
    a589 = None
    a590 = None
    a591 = None
    a592 = None
    a593 = None
    a594 = None
    a595 = None
    a596 = None
    a597 = None
    a598 = None
    a599 = None
    a600 = None
    a601 = None
    a602 = None
    a603 = None
    a604 = None
    a605 = None
    a606 = None
    a607 = None
    a608 = None
    a609 = None
    a610 = None
    a611 = None
    a612 = None
    a613 = None
    a614 = None
    a615 = None
    a616 = None
    a617 = None
    a618 = None
    a619 = None
    a620 = None
    a621 = None
    a622 = None
    a623 = None
    a624 = None
    a625 = None
    a626 = None
    a627 = None
    a628 = None
    a629 = None
    a630 = None
    a631 = None
    a632 = None
    a633 = None
    a634 = None
    a635 = None
    a636 = None
    a637 = None
    a638 = None
    a639 = None
    a640 = None
    a641 = None
    a642 = None
    a643 = None
    a644 = None
    a645 = None
    a646 = None
    a647 = None
    a648 = None
    a649 = None
    a650 = None
    a651 = None
    a652 = None
    a653 = None
    a654 = None
    a655 = None
    a656 = None
    a657 = None
    a658 = None
    a659 = None
    a660 = None
    a661 = None
    a662 = None
    a663 = None
    a664 = None
    a665 = None
    a666 = None
    a667 = None
    a668 = None
    a669 = None
    a670 = None
    a671 = None
    a672 = None
    a673 = None
    a674 = None
    a675 = None
    a676 = None
    a677 = None
    a678 = None
    a679 = None
    a680 = None
    a681 = None
    a682 = None
    a683 = None
    a684 = None
    a685 = None
    a686 = None
    a687 = None
    a688 = None
    a689 = None
    a690 = None
    a691 = None
    a692 = None
    a693 = None
    a694 = None
    a695 = None
    a696 = None
    a697 = None
    a698 = None
    a699 = None
    a700 = None
    a701 = None
    a702 = None
    a703 = None
    a704 = None
    a705 = None
    a706 = None
    a707 = None
    a708 = None
    a709 = None
    a710 = None
    a711 = None
    a712 = None
    a713 = None
    a714 = None
    a715 = None
    a716 = None
    a717 = None
    a718 = None
    a719 = None
    a720 = None
    a721 = None
    a722 = None
    a723 = None
    a724 = None
    a725 = None
    a726 = None
    a727 = None
    a728 = None
    a729 = None
    a730 = None
    a731 = None
    a732 = None
    a733 = None
    a734 = None
    a735 = None
    a736 = None
    a737 = None
    a738 = None
    a739 = None
    a740 = None
    a741 = None
    a742 = None
    a743 = None
    a744 = None
    a745 = None
    a746 = None
    a747 = None
    a748 = None
    a749 = None
    a750 = None
    a751 = None
    a752 = None
    a753 = None
    a754 = None
    a755 = None
    a756 = None
    a757 = None
    a758 = None
    a759 = None
    a760 = None
    a761 = None
    a762 = None
    a763 = None
    a764 = None
    a765 = None
    a766 = None
    a767 = None
    a768 = None
    a769 = None
    a770 = None
    a771 = None
    a772 = None
    a773 = None
    a774 = None
    a775 = None
    a776 = None
    a777 = None
    a778 = None
    a779 = None
    a780 = None
    a781 = None
    a782 = None
    a783 = None
    a784 = None
    a785 = None
    a786 = None
    a787 = None
    a788 = None
    a789 = None
    a790 = None
    a791 = None
    a792 = None
    a793 = None
    a794 = None
    a795 = None
    a796 = None
    a797 = None
    a798 = None
    a799 = None
    a800 = None
    a801 = None
    a802 = None
    a803 = None
    a804 = None
    a805 = None
    a806 = None
    a807 = None
    a808 = None
    a809 = None
    a810 = None
    a811 = None
    a812 = None
    a813 = None
    a814 = None
    a815 = None
    a816 = None
    a817 = None
    a818 = None
    a819 = None
    a820 = None
    a821 = None
    a822 = None
    a823 = None
    a824 = None
    a825 = None
    a826 = None
    a827 = None
    a828 = None
    a829 = None
    a830 = None
    a831 = None
    a832 = None
    a833 = None
    a834 = None
    a835 = None
    a836 = None
    a837 = None
    a838 = None
    a839 = None
    a840 = None
    a841 = None
    a842 = None
    a843 = None
    a844 = None
    a845 = None
    a846 = None
    a847 = None
    a848 = None
    a849 = None
    a850 = None
    a851 = None
    a852 = None
    a853 = None
    a854 = None
    a855 = None
    a856 = None
    a857 = None
    a858 = None
    a859 = None
    a860 = None
    a861 = None
    a862 = None
    a863 = None
    a864 = None
    a865 = None
    a866 = None
    a867 = None
    a868 = None
    a869 = None
    a870 = None
    a871 = None
    a872 = None
    a873 = None
    a874 = None
    a875 = None
    a876 = None
    a877 = None
    a878 = None
    a879 = None
    a880 = None
    a881 = None
    a882 = None
    a883 = None
    a884 = None
    a885 = None
    a886 = None
    a887 = None
    a888 = None
    a889 = None
    a890 = None
    a891 = None
    a892 = None
    a893 = None
    a894 = None
    a895 = None
    a896 = None
    a897 = None
    a898 = None
    a899 = None
    a900 = None
    a901 = None
    a902 = None
    a903 = None
    a904 = None
    a905 = None
    a906 = None
    a907 = None
    a908 = None
    a909 = None
    a910 = None
    a911 = None
    a912 = None
    a913 = None
    a914 = None
    a915 = None
    a916 = None
    a917 = None
    a918 = None
    a919 = None
    a920 = None
    a921 = None
    a922 = None
    a923 = None
    a924 = None
    a925 = None
    a926 = None
    a927 = None
    a928 = None
    a929 = None
    a930 = None
    a931 = None
    a932 = None
    a933 = None
    a934 = None
    a935 = None
    a936 = None
    a937 = None
    a938 = None
    a939 = None
    a940 = None
    a941 = None
    a942 = None
    a943 = None
    a944 = None
    a945 = None
    a946 = None
    a947 = None
    a948 = None
    a949 = None
    a950 = None
    a951 = None
    a952 = None
    a953 = None
    a954 = None
    a955 = None
    a956 = None
    a957 = None
    a958 = None
    a959 = None
    a960 = None
    a961 = None
    a962 = None
    a963 = None
    a964 = None
    a965 = None
    a966 = None
    a967 = None
    a968 = None
    a969 = None
    a970 = None
    a971 = None
    a972 = None
    a973 = None
    a974 = None
    a975 = None
    a976 = None
    a977 = None
    a978 = None
    a979 = None
    a980 = None
    a981 = None
    a982 = None
    a983 = None
    a984 = None
    a985 = None
    a986 = None
    a987 = None
    a988 = None
    a989 = None
    a990 = None
    a991 = None
    a992 = None
    a993 = None
    a994 = None
    a995 = None
    a996 = None
    a997 = None
    a998 = None
    a999 = None
    a1000 = None
    a1001 = None
    a1002 = None
    a1003 = None
    a1004 = None
    a1005 = None
    a1006 = None
    a1007 = None
    a1008 = None
    a1009 = None
    a1010 = None
    a1011 = None
    a1012 = None
    a1013 = None
    a1014 = None
    a1015 = None
    a1016 = None
    a1017 = None
    a1018 = None
    a1019 = None
    a1020 = None
    a1021 = None
    a1022 = None
    a1023 = None
    a1024 = None
    a1025 = None
    a1026 = None
    a1027 = None
    a1028 = None
    a1029 = None
    a1030 = None
    a1031 = None
    a1032 = None
    a1033 = None
    a1034 = None
    a1035 = None
    a1036 = None
    a1037 = None
    a1038 = None
    a1039 = None
    a1040 = None
    a1041 = None
    a1042 = None
    a1043 = None
    a1044 = None
    a1045 = None
    a1046 = None
    a1047 = None
    a1048 = None
    a1049 = None
    a1050 = None
    a1051 = None
    a1052 = None
    a1053 = None
    a1054 = None
    a1055 = None
    a1056 = None
    a1057 = None
    a1058 = None
    a1059 = None
    a1060 = None
    a1061 = None
    a1062 = None
    a1063 = None
    a1064 = None
    a1065 = None
    a1066 = None
    a1067 = None
    a1068 = None
    a1069 = None
    a1070 = None
    a1071 = None
    a1072 = None
    a1073 = None
    a1074 = None
    a1075 = None
    a1076 = None
    a1077 = None
    a1078 = None
    a1079 = None
    a1080 = None
    a1081 = None
    a1082 = None
    a1083 = None
    a1084 = None
    a1085 = None
    a1086 = None
    a1087 = None
    a1088 = None
    a1089 = None
    a1090 = None
    a1091 = None
    a1092 = None
    a1093 = None
    a1094 = None
    a1095 = None
    a1096 = None
    a1097 = None
    a1098 = None
    a1099 = None
    a1100 = None
    a1101 = None
    a1102 = None
    a1103 = None
    a1104 = None
    a1105 = None
    a1106 = None
    a1107 = None
    a1108 = None
    a1109 = None
    a1110 = None
    a1111 = None
    a1112 = None
    a1113 = None
    a1114 = None
    a1115 = None
    a1116 = None
    a1117 = None
    a1118 = None
    a1119 = None
    a1120 = None
    a1121 = None
    a1122 = None
    a1123 = None
    a1124 = None
    a1125 = None
    a1126 = None
    a1127 = None
    a1128 = None
    a1129 = None
    a1130 = None
    a1131 = None
    a1132 = None
    a1133 = None
    a1134 = None
    a1135 = None
    a1136 = None
    a1137 = None
    a1138 = None
    a1139 = None
    a1140 = None
    a1141 = None
    a1142 = None
    a1143 = None
    a1144 = None
    a1145 = None
    a1146 = None
    a1147 = None
    a1148 = None
    a1149 = None
    a1150 = None
    a1151 = None
    a1152 = None
    a1153 = None
    a1154 = None
    a1155 = None
    a1156 = None
    a1157 = None
    a1158 = None
    a1159 = None
    a1160 = None
    a1161 = None
    a1162 = None
    a1163 = None
    a1164 = None
    a1165 = None
    a1166 = None
    a1167 = None
    a1168 = None
    a1169 = None
    a1170 = None
    a1171 = None
    a1172 = None
    a1173 = None
    a1174 = None
    a1175 = None
    a1176 = None
    a1177 = None
    a1178 = None
    a1179 = None
    a1180 = None
    a1181 = None
    a1182 = None
    a1183 = None
    a1184 = None
    a1185 = None
    a1186 = None
    a1187 = None
    a1188 = None
    a1189 = None
    a1190 = None
    a1191 = None
    a1192 = None
    a1193 = None
    a1194 = None
    a1195 = None
    a1196 = None
    a1197 = None
    a1198 = None
    a1199 = None
    a1200 = None
    a1201 = None
    a1202 = None
    a1203 = None
    a1204 = None
    a1205 = None
    a1206 = None
    a1207 = None
    a1208 = None
    a1209 = None
    a1210 = None
    a1211 = None
    a1212 = None
    a1213 = None
    a1214 = None
    a1215 = None
    a1216 = None
    a1217 = None
    a1218 = None
    a1219 = None
    a1220 = None
    a1221 = None
    a1222 = None
    a1223 = None
    a1224 = None
    a1225 = None
    a1226 = None
    a1227 = None
    a1228 = None
    a1229 = None
    a1230 = None
    a1231 = None
    a1232 = None
    a1233 = None
    a1234 = None
    a1235 = None
    a1236 = None
    a1237 = None
    a1238 = None
    a1239 = None
    a1240 = None
    a1241 = None
    a1242 = None
    a1243 = None
    a1244 = None
    a1245 = None
    a1246 = None
    a1247 = None
    a1248 = None
    a1249 = None
    a1250 = None
    a1251 = None
    a1252 = None
    a1253 = None
    a1254 = None
    a1255 = None
    a1256 = None
    a1257 = None
    a1258 = None
    a1259 = None
    a1260 = None
    a1261 = None
    a1262 = None
    a1263 = None
    a1264 = None
    a1265 = None
    a1266 = None
    a1267 = None
    a1268 = None
    a1269 = None
    a1270 = None
    a1271 = None
    a1272 = None
    a1273 = None
    a1274 = None
    a1275 = None
    a1276 = None
    a1277 = None
    a1278 = None
    a1279 = None
    a1280 = None
    a1281 = None
    a1282 = None
    a1283 = None
    a1284 = None
    a1285 = None
    a1286 = None
    a1287 = None
    a1288 = None
    a1289 = None
    a1290 = None
    a1291 = None
    a1292 = None
    a1293 = None
    a1294 = None
    a1295 = None
    a1296 = None
    a1297 = None
    a1298 = None
    a1299 = None
    a1300 = None
    a1301 = None
    a1302 = None
    a1303 = None
    a1304 = None
    a1305 = None
    a1306 = None
    a1307 = None
    a1308 = None
    a1309 = None
    a1310 = None
    a1311 = None
    a1312 = None
    a1313 = None
    a1314 = None
    a1315 = None
    a1316 = None
    a1317 = None
    a1318 = None
    a1319 = None
    a1320 = None
    a1321 = None
    a1322 = None
    a1323 = None
    a1324 = None
    a1325 = None
    a1326 = None
    a1327 = None
    a1328 = None
    a1329 = None
    a1330 = None
    a1331 = None
    a1332 = None
    a1333 = None
    a1334 = None
    a1335 = None
    a1336 = None
    a1337 = None
    a1338 = None
    a1339 = None
    a1340 = None
    a1341 = None
    a1342 = None
    a1343 = None
    a1344 = None
    a1345 = None
    a1346 = None
    a1347 = None
    a1348 = None
    a1349 = None
    a1350 = None
    a1351 = None
    a1352 = None
    a1353 = None
    a1354 = None
    a1355 = None
    a1356 = None
    a1357 = None
    a1358 = None
    a1359 = None
    a1360 = None
    a1361 = None
    a1362 = None
    a1363 = None
    a1364 = None
    a1365 = None
    a1366 = None
    a1367 = None
    a1368 = None
    a1369 = None
    a1370 = None
    a1371 = None
    a1372 = None
    a1373 = None
    a1374 = None
    a1375 = None
    a1376 = None
    a1377 = None
    a1378 = None
    a1379 = None
    a1380 = None
    a1381 = None
    a1382 = None
    a1383 = None
    a1384 = None
    a1385 = None
    a1386 = None
    a1387 = None
    a1388 = None
    a1389 = None
    a1390 = None
    a1391 = None
    a1392 = None
    a1393 = None
    a1394 = None
    a1395 = None
    a1396 = None
    a1397 = None
    a1398 = None
    a1399 = None
    a1400 = None
    a1401 = None
    a1402 = None
    a1403 = None
    a1404 = None
    a1405 = None
    a1406 = None
    a1407 = None
    a1408 = None
    a1409 = None
    a1410 = None
    a1411 = None
    a1412 = None
    a1413 = None
    a1414 = None
    a1415 = None
    a1416 = None
    a1417 = None
    a1418 = None
    a1419 = None
    a1420 = None
    a1421 = None
    a1422 = None
    a1423 = None
    a1424 = None
    a1425 = None
    a1426 = None
    a1427 = None
    a1428 = None
    a1429 = None
    a1430 = None
    a1431 = None
    a1432 = None
    a1433 = None
    a1434 = None
    a1435 = None
    a1436 = None
    a1437 = None
    a1438 = None
    a1439 = None
    a1440 = None
    a1441 = None
    a1442 = None
    a1443 = None
    a1444 = None
    a1445 = None
    a1446 = None
    a1447 = None
    a1448 = None
    a1449 = None
    a1450 = None
    a1451 = None
    a1452 = None
    a1453 = None
    a1454 = None
    a1455 = None
    a1456 = None
    a1457 = None
    a1458 = None
    a1459 = None
    a1460 = None
    a1461 = None
    a1462 = None
    a1463 = None
    a1464 = None
    a1465 = None
    a1466 = None
    a1467 = None
    a1468 = None
    a1469 = None
    a1470 = None
    a1471 = None
    a1472 = None
    a1473 = None
    a1474 = None
    a1475 = None
    a1476 = None
    a1477 = None
    a1478 = None
    a1479 = None
    a1480 = None
    a1481 = None
    a1482 = None
    a1483 = None
    a1484 = None
    a1485 = None
    a1486 = None
    a1487 = None
    a1488 = None
    a1489 = None
    a1490 = None
    a1491 = None
    a1492 = None
    a1493 = None
    a1494 = None
    a1495 = None
    a1496 = None
    a1497 = None
    a1498 = None
    a1499 = None
    a1500 = None
    a1501 = None
    a1502 = None
    a1503 = None
    a1504 = None
    a1505 = None
    a1506 = None
    a1507 = None
    a1508 = None
    a1509 = None
    a1510 = None
    a1511 = None
    a1512 = None
    a1513 = None
    a1514 = None
    a1515 = None
    a1516 = None
    a1517 = None
    a1518 = None
    a1519 = None
    a1520 = None
    a1521 = None
    a1522 = None
    a1523 = None
    a1524 = None
    a1525 = None
    a1526 = None
    a1527 = None
    a1528 = None
    a1529 = None
    a1530 = None
    a1531 = None
    a1532 = None
    a1533 = None
    a1534 = None
    a1535 = None
    a1536 = None
    a1537 = None
    a1538 = None
    a1539 = None
    a1540 = None
    a1541 = None
    a1542 = None
    a1543 = None
    a1544 = None
    a1545 = None
    a1546 = None
    a1547 = None
    a1548 = None
    a1549 = None
    a1550 = None
    a1551 = None
    a1552 = None
    a1553 = None
    a1554 = None
    a1555 = None
    a1556 = None
    a1557 = None
    a1558 = None
    a1559 = None
    a1560 = None
    a1561 = None
    a1562 = None
    a1563 = None
    a1564 = None
    a1565 = None
    a1566 = None
    a1567 = None
    a1568 = None
    a1569 = None
    a1570 = None
    a1571 = None
    a1572 = None
    a1573 = None
    a1574 = None
    a1575 = None
    a1576 = None
    a1577 = None
    a1578 = None
    a1579 = None
    a1580 = None
    a1581 = None
    a1582 = None
    a1583 = None
    a1584 = None
    a1585 = None
    a1586 = None
    a1587 = None
    a1588 = None
    a1589 = None
    a1590 = None
    a1591 = None
    a1592 = None
    a1593 = None
    a1594 = None
    a1595 = None
    a1596 = None
    a1597 = None
    a1598 = None
    a1599 = None
    a1600 = None
    a1601 = None
    a1602 = None
    a1603 = None
    a1604 = None
    a1605 = None
    a1606 = None
    a1607 = None
    a1608 = None
    a1609 = None
    a1610 = None
    a1611 = None
    a1612 = None
    a1613 = None
    a1614 = None
    a1615 = None
    a1616 = None
    a1617 = None
    a1618 = None
    a1619 = None
    a1620 = None
    a1621 = None
    a1622 = None
    a1623 = None
    a1624 = None
    a1625 = None
    a1626 = None
    a1627 = None
    a1628 = None
    a1629 = None
    a1630 = None
    a1631 = None
    a1632 = None
    a1633 = None
    a1634 = None
    a1635 = None
    a1636 = None
    a1637 = None
    a1638 = None
    a1639 = None
    a1640 = None
    a1641 = None
    a1642 = None
    a1643 = None
    a1644 = None
    a1645 = None
    a1646 = None
    a1647 = None
    a1648 = None
    a1649 = None
    a1650 = None
    a1651 = None
    a1652 = None
    a1653 = None
    a1654 = None
    a1655 = None
    a1656 = None
    a1657 = None
    a1658 = None
    a1659 = None
    a1660 = None
    a1661 = None
    a1662 = None
    a1663 = None
    a1664 = None
    a1665 = None
    a1666 = None
    a1667 = None
    a1668 = None
    a1669 = None
    a1670 = None
    a1671 = None
    a1672 = None
    a1673 = None
    a1674 = None
    a1675 = None
    a1676 = None
    a1677 = None
    a1678 = None
    a1679 = None
    a1680 = None
    a1681 = None
    a1682 = None
    a1683 = None
    a1684 = None
    a1685 = None
    a1686 = None
    a1687 = None
    a1688 = None
    a1689 = None
    a1690 = None
    a1691 = None
    a1692 = None
    a1693 = None
    a1694 = None
    a1695 = None
    a1696 = None
    a1697 = None
    a1698 = None
    a1699 = None
    a1700 = None
    a1701 = None
    a1702 = None
    a1703 = None
    a1704 = None
    a1705 = None
    a1706 = None
    a1707 = None
    a1708 = None
    a1709 = None
    a1710 = None
    a1711 = None
    a1712 = None
    a1713 = None
    a1714 = None
    a1715 = None
    a1716 = None
    a1717 = None
    a1718 = None
    a1719 = None
    a1720 = None
    a1721 = None
    a1722 = None
    a1723 = None
    a1724 = None
    a1725 = None
    a1726 = None
    a1727 = None
    a1728 = None
    a1729 = None
    a1730 = None
    a1731 = None
    a1732 = None
    a1733 = None
    a1734 = None
    a1735 = None
    a1736 = None
    a1737 = None
    a1738 = None
    a1739 = None
    a1740 = None
    a1741 = None
    a1742 = None
    a1743 = None
    a1744 = None
    a1745 = None
    a1746 = None
    a1747 = None
    a1748 = None
    a1749 = None
    a1750 = None
    a1751 = None
    a1752 = None
    a1753 = None
    a1754 = None
    a1755 = None
    a1756 = None
    a1757 = None
    a1758 = None
    a1759 = None
    a1760 = None
    a1761 = None
    a1762 = None
    a1763 = None
    a1764 = None
    a1765 = None
    a1766 = None
    a1767 = None
    a1768 = None
    a1769 = None
    a1770 = None
    a1771 = None
    a1772 = None
    a1773 = None
    a1774 = None
    a1775 = None
    a1776 = None
    a1777 = None
    a1778 = None
    a1779 = None
    a1780 = None
    a1781 = None
    a1782 = None
    a1783 = None
    a1784 = None
    a1785 = None
    a1786 = None
    a1787 = None
    a1788 = None
    a1789 = None
    a1790 = None
    a1791 = None
    a1792 = None
    a1793 = None
    a1794 = None
    a1795 = None
    a1796 = None
    a1797 = None
    a1798 = None
    a1799 = None
    a1800 = None
    a1801 = None
    a1802 = None
    a1803 = None
    a1804 = None
    a1805 = None
    a1806 = None
    a1807 = None
    a1808 = None
    a1809 = None
    a1810 = None
    a1811 = None
    a1812 = None
    a1813 = None
    a1814 = None
    a1815 = None
    a1816 = None
    a1817 = None
    a1818 = None
    a1819 = None
    a1820 = None
    a1821 = None
    a1822 = None
    a1823 = None
    a1824 = None
    a1825 = None
    a1826 = None
    a1827 = None
    a1828 = None
    a1829 = None
    a1830 = None
    a1831 = None
    a1832 = None
    a1833 = None
    a1834 = None
    a1835 = None
    a1836 = None
    a1837 = None
    a1838 = None
    a1839 = None
    a1840 = None
    a1841 = None
    a1842 = None
    a1843 = None
    a1844 = None
    a1845 = None
    a1846 = None
    a1847 = None
    a1848 = None
    a1849 = None
    a1850 = None
    a1851 = None
    a1852 = None
    a1853 = None
    a1854 = None
    a1855 = None
    a1856 = None
    a1857 = None
    a1858 = None
    a1859 = None
    a1860 = None
    a1861 = None
    a1862 = None
    a1863 = None
    a1864 = None
    a1865 = None
    a1866 = None
    a1867 = None
    a1868 = None
    a1869 = None
    a1870 = None
    a1871 = None
    a1872 = None
    a1873 = None
    a1874 = None
    a1875 = None
    a1876 = None
    a1877 = None
    a1878 = None
    a1879 = None
    a1880 = None
    a1881 = None
    a1882 = None
    a1883 = None
    a1884 = None
    a1885 = None
    a1886 = None
    a1887 = None
    a1888 = None
    a1889 = None
    a1890 = None
    a1891 = None
    a1892 = None
    a1893 = None
    a1894 = None
    a1895 = None
    a1896 = None
    a1897 = None
    a1898 = None
    a1899 = None
    a1900 = None
    a1901 = None
    a1902 = None
    a1903 = None
    a1904 = None
    a1905 = None
    a1906 = None
    a1907 = None
    a1908 = None
    a1909 = None
    a1910 = None
    a1911 = None
    a1912 = None
    a1913 = None
    a1914 = None
    a1915 = None
    a1916 = None
    a1917 = None
    a1918 = None
    a1919 = None
    a1920 = None
    a1921 = None
    a1922 = None
    a1923 = None
    a1924 = None
    a1925 = None
    a1926 = None
    a1927 = None
    a1928 = None
    a1929 = None
    a1930 = None
    a1931 = None
    a1932 = None
    a1933 = None
    a1934 = None
    a1935 = None
    a1936 = None
    a1937 = None
    a1938 = None
    a1939 = None
    a1940 = None
    a1941 = None
    a1942 = None
    a1943 = None
    a1944 = None
    a1945 = None
    a1946 = None
    a1947 = None
    a1948 = None
    a1949 = None
    a1950 = None
    a1951 = None
    a1952 = None
    a1953 = None
    a1954 = None
    a1955 = None
    a1956 = None
    a1957 = None
    a1958 = None
    a1959 = None
    a1960 = None
    a1961 = None
    a1962 = None
    a1963 = None
    a1964 = None
    a1965 = None
    a1966 = None
    a1967 = None
    a1968 = None
    a1969 = None
    a1970 = None
    a1971 = None
    a1972 = None
    a1973 = None
    a1974 = None
    a1975 = None
    a1976 = None
    a1977 = None
    a1978 = None
    a1979 = None
    a1980 = None
    a1981 = None
    a1982 = None
    a1983 = None
    a1984 = None
    a1985 = None
    a1986 = None
    a1987 = None
    a1988 = None
    a1989 = None
    a1990 = None
    a1991 = None
    a1992 = None
    a1993 = None
    a1994 = None
    a1995 = None
    a1996 = None
    a1997 = None
    a1998 = None
    a1999 = None
    a2000 = None
    a2001 = None
    a2002 = None
    a2003 = None
    a2004 = None
    a2005 = None
    a2006 = None
    a2007 = None
    a2008 = None
    a2009 = None
    a2010 = None
    a2011 = None
    a2012 = None
    a2013 = None
    a2014 = None
    a2015 = None
    a2016 = None
    a2017 = None
    a2018 = None
    a2019 = None
    a2020 = None
    a2021 = None
    a2022 = None
    a2023 = None
    a2024 = None
    a2025 = None
    a2026 = None
    a2027 = None
    a2028 = None
    a2029 = None
    a2030 = None
    a2031 = None
    a2032 = None
    a2033 = None
    a2034 = None
    a2035 = None
    a2036 = None
    a2037 = None
    a2038 = None
    a2039 = None
    a2040 = None
    a2041 = None
    a2042 = None
    a2043 = None
    a2044 = None
    a2045 = None
    a2046 = None
    a2047 = None
    a2048 = None
    a2049 = None
    a2050 = None
    a2051 = None
    a2052 = None
    a2053 = None
    a2054 = None
    a2055 = None
    a2056 = None
    a2057 = None
    a2058 = None
    a2059 = None
    a2060 = None
    a2061 = None
    a2062 = None
    a2063 = None
    a2064 = None
    a2065 = None
    a2066 = None
    a2067 = None
    a2068 = None
    a2069 = None
    a2070 = None
    a2071 = None
    a2072 = None
    a2073 = None
    a2074 = None
    a2075 = None
    a2076 = None
    a2077 = None
    a2078 = None
    a2079 = None
    a2080 = None
    a2081 = None
    a2082 = None
    a2083 = None
    a2084 = None
    a2085 = None
    a2086 = None
    a2087 = None
    a2088 = None
    a2089 = None
    a2090 = None
    a2091 = None
    a2092 = None
    a2093 = None
    a2094 = None
    a2095 = None
    a2096 = None
    a2097 = None
    a2098 = None
    a2099 = None
    a2100 = None
    a2101 = None
    a2102 = None
    a2103 = None
    a2104 = None
    a2105 = None
    a2106 = None
    a2107 = None
    a2108 = None
    a2109 = None
    a2110 = None
    a2111 = None
    a2112 = None
    a2113 = None
    a2114 = None
    a2115 = None
    a2116 = None
    a2117 = None
    a2118 = None
    a2119 = None
    a2120 = None
    a2121 = None
    a2122 = None
    a2123 = None
    a2124 = None
    a2125 = None
    a2126 = None
    a2127 = None
    a2128 = None
    a2129 = None
    a2130 = None
    a2131 = None
    a2132 = None
    a2133 = None
    a2134 = None
    a2135 = None
    a2136 = None
    a2137 = None
    a2138 = None
    a2139 = None
    a2140 = None
    a2141 = None
    a2142 = None
    a2143 = None
    a2144 = None
    a2145 = None
    a2146 = None
    a2147 = None
    a2148 = None
    a2149 = None
    a2150 = None
    a2151 = None
    a2152 = None
    a2153 = None
    a2154 = None
    a2155 = None
    a2156 = None
    a2157 = None
    a2158 = None
    a2159 = None
    a2160 = None
    a2161 = None
    a2162 = None
    a2163 = None
    a2164 = None
    a2165 = None
    a2166 = None
    a2167 = None
    a2168 = None
    a2169 = None
    a2170 = None
    a2171 = None
    a2172 = None
    a2173 = None
    a2174 = None
    a2175 = None
    a2176 = None
    a2177 = None
    a2178 = None
    a2179 = None
    a2180 = None
    a2181 = None
    a2182 = None
    a2183 = None
    a2184 = None
    a2185 = None
    a2186 = None
    a2187 = None
    a2188 = None
    a2189 = None
    a2190 = None
    a2191 = None
    a2192 = None
    a2193 = None
    a2194 = None
    a2195 = None
    a2196 = None
    a2197 = None
    a2198 = None
    a2199 = None
    a2200 = None
    a2201 = None
    a2202 = None
    a2203 = None
    a2204 = None
    a2205 = None
    a2206 = None
    a2207 = None
    a2208 = None
    a2209 = None
    a2210 = None
    a2211 = None
    a2212 = None
    a2213 = None
    a2214 = None
    a2215 = None
    a2216 = None
    a2217 = None
    a2218 = None
    a2219 = None
    a2220 = None
    a2221 = None
    a2222 = None
    a2223 = None
    a2224 = None
    a2225 = None
    a2226 = None
    a2227 = None
    a2228 = None
    a2229 = None
    a2230 = None
    a2231 = None
    a2232 = None
    a2233 = None
    a2234 = None
    a2235 = None
    a2236 = None
    a2237 = None
    a2238 = None
    a2239 = None
    a2240 = None
    a2241 = None
    a2242 = None
    a2243 = None
    a2244 = None
    a2245 = None
    a2246 = None
    a2247 = None
    a2248 = None
    a2249 = None
    a2250 = None
    a2251 = None
    a2252 = None
    a2253 = None
    a2254 = None
    a2255 = None
    a2256 = None
    a2257 = None
    a2258 = None
    a2259 = None
    a2260 = None
    a2261 = None
    a2262 = None
    a2263 = None
    a2264 = None
    a2265 = None
    a2266 = None
    a2267 = None
    a2268 = None
    a2269 = None
    a2270 = None
    a2271 = None
    a2272 = None
    a2273 = None
    a2274 = None
    a2275 = None
    a2276 = None
    a2277 = None
    a2278 = None
    a2279 = None
    a2280 = None
    a2281 = None
    a2282 = None
    a2283 = None
    a2284 = None
    a2285 = None
    a2286 = None
    a2287 = None
    a2288 = None
    a2289 = None
    a2290 = None
    a2291 = None
    a2292 = None
    a2293 = None
    a2294 = None
    a2295 = None
    a2296 = None
    a2297 = None
    a2298 = None
    a2299 = None
    a2300 = None
    a2301 = None
    a2302 = None
    a2303 = None
    a2304 = None
    a2305 = None
    a2306 = None
    a2307 = None
    a2308 = None
    a2309 = None
    a2310 = None
    a2311 = None
    a2312 = None
    a2313 = None
    a2314 = None
    a2315 = None
    a2316 = None
    a2317 = None
    a2318 = None
    a2319 = None
    a2320 = None
    a2321 = None
    a2322 = None
    a2323 = None
    a2324 = None
    a2325 = None
    a2326 = None
    a2327 = None
    a2328 = None
    a2329 = None
    a2330 = None
    a2331 = None
    a2332 = None
    a2333 = None
    a2334 = None
    a2335 = None
    a2336 = None
    a2337 = None
    a2338 = None
    a2339 = None
    a2340 = None
    a2341 = None
    a2342 = None
    a2343 = None
    a2344 = None
    a2345 = None
    a2346 = None
    a2347 = None
    a2348 = None
    a2349 = None
    a2350 = None
    a2351 = None
    a2352 = None
    a2353 = None
    a2354 = None
    a2355 = None
    a2356 = None
    a2357 = None
    a2358 = None
    a2359 = None
    a2360 = None
    a2361 = None
    a2362 = None
    a2363 = None
    a2364 = None
    a2365 = None
    a2366 = None
    a2367 = None
    a2368 = None
    a2369 = None
    a2370 = None
    a2371 = None
    a2372 = None
    a2373 = None
    a2374 = None
    a2375 = None
    a2376 = None
    a2377 = None
    a2378 = None
    a2379 = None
    a2380 = None
    a2381 = None
    a2382 = None
    a2383 = None
    a2384 = None
    a2385 = None
    a2386 = None
    a2387 = None
    a2388 = None
    a2389 = None
    a2390 = None
    a2391 = None
    a2392 = None
    a2393 = None
    a2394 = None
    a2395 = None
    a2396 = None
    a2397 = None
    a2398 = None
    a2399 = None
    a2400 = None
    a2401 = None
    a2402 = None
    a2403 = None
    a2404 = None
    a2405 = None
    a2406 = None
    a2407 = None
    a2408 = None
    a2409 = None
    a2410 = None
    a2411 = None
    a2412 = None
    a2413 = None
    a2414 = None
    a2415 = None
    a2416 = None
    a2417 = None
    a2418 = None
    a2419 = None
    a2420 = None
    a2421 = None
    a2422 = None
    a2423 = None
    a2424 = None
    a2425 = None
    a2426 = None
    a2427 = None
    a2428 = None
    a2429 = None
    a2430 = None
    a2431 = None
    a2432 = None
    a2433 = None
    a2434 = None
    a2435 = None
    a2436 = None
    a2437 = None
    a2438 = None
    a2439 = None
    a2440 = None
    a2441 = None
    a2442 = None
    a2443 = None
    a2444 = None
    a2445 = None
    a2446 = None
    a2447 = None
    a2448 = None
    a2449 = None
    a2450 = None
    a2451 = None
    a2452 = None
    a2453 = None
    a2454 = None
    a2455 = None
    a2456 = None
    a2457 = None
    a2458 = None
    a2459 = None
    a2460 = None
    a2461 = None
    a2462 = None
    a2463 = None
    a2464 = None
    a2465 = None
    a2466 = None
    a2467 = None
    a2468 = None
    a2469 = None
    a2470 = None
    a2471 = None
    a2472 = None
    a2473 = None
    a2474 = None
    a2475 = None
    a2476 = None
    a2477 = None
    a2478 = None
    a2479 = None
    a2480 = None
    a2481 = None
    a2482 = None
    a2483 = None
    a2484 = None
    a2485 = None
    a2486 = None
    a2487 = None
    a2488 = None
    a2489 = None
    a2490 = None
    a2491 = None
    a2492 = None
    a2493 = None
    a2494 = None
    a2495 = None
    a2496 = None
    a2497 = None
    a2498 = None
    a2499 = None
    a2500 = None
    a2501 = None
    a2502 = None
    a2503 = None
    a2504 = None
    a2505 = None
    a2506 = None
    a2507 = None
    a2508 = None
    a2509 = None
    a2510 = None
    a2511 = None
    a2512 = None
    a2513 = None
    a2514 = None
    a2515 = None
    a2516 = None
    a2517 = None
    a2518 = None
    a2519 = None
    a2520 = None
    a2521 = None
    a2522 = None
    a2523 = None
    a2524 = None
    a2525 = None
    a2526 = None
    a2527 = None
    a2528 = None
    a2529 = None
    a2530 = None
    a2531 = None
    a2532 = None
    a2533 = None
    a2534 = None
    a2535 = None
    a2536 = None
    a2537 = None
    a2538 = None
    a2539 = None
    a2540 = None
    a2541 = None
    a2542 = None
    a2543 = None
    a2544 = None
    a2545 = None
    a2546 = None
    a2547 = None
    a2548 = None
    a2549 = None
    a2550 = None
    a2551 = None
    a2552 = None
    a2553 = None
    a2554 = None
    a2555 = None
    a2556 = None
    a2557 = None
    a2558 = None
    a2559 = None
    a2560 = None
    a2561 = None
    a2562 = None
    a2563 = None
    a2564 = None
    a2565 = None
    a2566 = None
    a2567 = None
    a2568 = None
    a2569 = None
    a2570 = None
    a2571 = None
    a2572 = None
    a2573 = None
    a2574 = None
    a2575 = None
    a2576 = None
    a2577 = None
    a2578 = None
    a2579 = None
    a2580 = None
    a2581 = None
    a2582 = None
    a2583 = None
    a2584 = None
    
# with "other_thing" which is nonlocal but not declared, and is linked to global "thing"
Instruction(opname='LOAD_DEREF', opcode=136, arg=1, argval='x', argrepr='x', offset=0, starts_line=6, is_jump_target=False)
Instruction(opname='LOAD_CONST', opcode=100, arg=1, argval=1, argrepr='1', offset=2, starts_line=None, is_jump_target=False)
Instruction(opname='INPLACE_ADD', opcode=55, arg=None, argval=None, argrepr='', offset=4, starts_line=None, is_jump_target=False)
Instruction(opname='STORE_DEREF', opcode=137, arg=1, argval='x', argrepr='x', offset=6, starts_line=None, is_jump_target=False)
Instruction(opname='LOAD_CONST', opcode=100, arg=2, argval=0, argrepr='0', offset=8, starts_line=7, is_jump_target=False)
Instruction(opname='LOAD_CONST', opcode=100, arg=3, argval=('print',), argrepr="('print',)", offset=10, starts_line=None, is_jump_target=False)
Instruction(opname='IMPORT_NAME', opcode=108, arg=0, argval='builtins', argrepr='builtins', offset=12, starts_line=None, is_jump_target=False)
Instruction(opname='IMPORT_FROM', opcode=109, arg=1, argval='print', argrepr='print', offset=14, starts_line=None, is_jump_target=False)
Instruction(opname='STORE_FAST', opcode=125, arg=0, argval='print', argrepr='print', offset=16, starts_line=None, is_jump_target=False)
Instruction(opname='POP_TOP', opcode=1, arg=None, argval=None, argrepr='', offset=18, starts_line=None, is_jump_target=False)
Instruction(opname='LOAD_FAST', opcode=124, arg=0, argval='print', argrepr='print', offset=20, starts_line=8, is_jump_target=False)
Instruction(opname='LOAD_DEREF', opcode=136, arg=1, argval='x', argrepr='x', offset=22, starts_line=None, is_jump_target=False)
Instruction(opname='CALL_FUNCTION', opcode=131, arg=1, argval=1, argrepr='', offset=24, starts_line=None, is_jump_target=False)
Instruction(opname='POP_TOP', opcode=1, arg=None, argval=None, argrepr='', offset=26, starts_line=None, is_jump_target=False)
Instruction(opname='LOAD_CONST', opcode=100, arg=4, argval=77, argrepr='77', offset=28, starts_line=9, is_jump_target=False)
Instruction(opname='LOAD_DEREF', opcode=136, arg=0, argval='other_thing', argrepr='other_thing', offset=30, starts_line=None, is_jump_target=False)
Instruction(opname='LOAD_CONST', opcode=100, arg=5, argval='hi', argrepr="'hi'", offset=32, starts_line=None, is_jump_target=False)
Instruction(opname='STORE_SUBSCR', opcode=60, arg=None, argval=None, argrepr='', offset=34, starts_line=None, is_jump_target=False)
Instruction(opname='LOAD_CONST', opcode=100, arg=0, argval=None, argrepr='None', offset=36, starts_line=None, is_jump_target=False)
Instruction(opname='RETURN_VALUE', opcode=83, arg=None, argval=None, argrepr='', offset=38, starts_line=None, is_jump_target=False)

# local "other_thing"
Instruction(opname='BUILD_MAP', opcode=105, arg=0, argval=0, argrepr='', offset=0, starts_line=5, is_jump_target=False)
Instruction(opname='STORE_FAST', opcode=125, arg=0, argval='other_thing', argrepr='other_thing', offset=2, starts_line=None, is_jump_target=False)
Instruction(opname='LOAD_DEREF', opcode=136, arg=0, argval='x', argrepr='x', offset=4, starts_line=7, is_jump_target=False)
Instruction(opname='LOAD_CONST', opcode=100, arg=1, argval=1, argrepr='1', offset=6, starts_line=None, is_jump_target=False)
Instruction(opname='INPLACE_ADD', opcode=55, arg=None, argval=None, argrepr='', offset=8, starts_line=None, is_jump_target=False)
Instruction(opname='STORE_DEREF', opcode=137, arg=0, argval='x', argrepr='x', offset=10, starts_line=None, is_jump_target=False)
Instruction(opname='LOAD_CONST', opcode=100, arg=2, argval=0, argrepr='0', offset=12, starts_line=8, is_jump_target=False)
Instruction(opname='LOAD_CONST', opcode=100, arg=3, argval=('print',), argrepr="('print',)", offset=14, starts_line=None, is_jump_target=False)
Instruction(opname='IMPORT_NAME', opcode=108, arg=0, argval='builtins', argrepr='builtins', offset=16, starts_line=None, is_jump_target=False)
Instruction(opname='IMPORT_FROM', opcode=109, arg=1, argval='print', argrepr='print', offset=18, starts_line=None, is_jump_target=False)
Instruction(opname='STORE_FAST', opcode=125, arg=1, argval='print', argrepr='print', offset=20, starts_line=None, is_jump_target=False)
Instruction(opname='POP_TOP', opcode=1, arg=None, argval=None, argrepr='', offset=22, starts_line=None, is_jump_target=False)
Instruction(opname='LOAD_FAST', opcode=124, arg=1, argval='print', argrepr='print', offset=24, starts_line=9, is_jump_target=False)
Instruction(opname='LOAD_DEREF', opcode=136, arg=0, argval='x', argrepr='x', offset=26, starts_line=None, is_jump_target=False)
Instruction(opname='CALL_FUNCTION', opcode=131, arg=1, argval=1, argrepr='', offset=28, starts_line=None, is_jump_target=False)
Instruction(opname='POP_TOP', opcode=1, arg=None, argval=None, argrepr='', offset=30, starts_line=None, is_jump_target=False)
Instruction(opname='LOAD_CONST', opcode=100, arg=4, argval=77, argrepr='77', offset=32, starts_line=10, is_jump_target=False)
Instruction(opname='LOAD_FAST', opcode=124, arg=0, argval='other_thing', argrepr='other_thing', offset=34, starts_line=None, is_jump_target=False)
Instruction(opname='LOAD_CONST', opcode=100, arg=5, argval='hi', argrepr="'hi'", offset=36, starts_line=None, is_jump_target=False)
Instruction(opname='STORE_SUBSCR', opcode=60, arg=None, argval=None, argrepr='', offset=38, starts_line=None, is_jump_target=False)
Instruction(opname='LOAD_CONST', opcode=100, arg=0, argval=None, argrepr='None', offset=40, starts_line=None, is_jump_target=False)
Instruction(opname='RETURN_VALUE', opcode=83, arg=None, argval=None, argrepr='', offset=42, starts_line=None, is_jump_target=False)




Instruction(opname='COPY_FREE_VARS', opcode=149, arg=1, argval=1, argrepr='', offset=0, starts_line=None, is_jump_target=False, positions=Positions(lineno=None, end_lineno=None, col_offset=None, end_col_offset=None))
Instruction(opname='MAKE_CELL', opcode=135, arg=2, argval='other_thing', argrepr='other_thing', offset=2, starts_line=None, is_jump_target=False, positions=Positions(lineno=None, end_lineno=None, col_offset=None, end_col_offset=None))
Instruction(opname='RESUME', opcode=151, arg=0, argval=0, argrepr='', offset=4, starts_line=4, is_jump_target=False, positions=Positions(lineno=4, end_lineno=4, col_offset=0, end_col_offset=0))
Instruction(opname='BUILD_MAP', opcode=105, arg=0, argval=0, argrepr='', offset=6, starts_line=5, is_jump_target=False, positions=Positions(lineno=5, end_lineno=5, col_offset=22, end_col_offset=24))
Instruction(opname='STORE_DEREF', opcode=138, arg=2, argval='other_thing', argrepr='other_thing', offset=8, starts_line=None, is_jump_target=False, positions=Positions(lineno=5, end_lineno=5, col_offset=8, end_col_offset=19))
Instruction(opname='LOAD_DEREF', opcode=137, arg=3, argval='x', argrepr='x', offset=10, starts_line=7, is_jump_target=False, positions=Positions(lineno=7, end_lineno=7, col_offset=8, end_col_offset=9))
Instruction(opname='LOAD_CONST', opcode=100, arg=1, argval=1, argrepr='1', offset=12, starts_line=None, is_jump_target=False, positions=Positions(lineno=7, end_lineno=7, col_offset=13, end_col_offset=14))
Instruction(opname='BINARY_OP', opcode=122, arg=13, argval=13, argrepr='+=', offset=14, starts_line=None, is_jump_target=False, positions=Positions(lineno=7, end_lineno=7, col_offset=8, end_col_offset=14))
Instruction(opname='STORE_DEREF', opcode=138, arg=3, argval='x', argrepr='x', offset=18, starts_line=None, is_jump_target=False, positions=Positions(lineno=7, end_lineno=7, col_offset=8, end_col_offset=9))
Instruction(opname='LOAD_CONST', opcode=100, arg=2, argval=0, argrepr='0', offset=20, starts_line=8, is_jump_target=False, positions=Positions(lineno=8, end_lineno=8, col_offset=8, end_col_offset=34))
Instruction(opname='LOAD_CONST', opcode=100, arg=3, argval=('print',), argrepr="('print',)", offset=22, starts_line=None, is_jump_target=False, positions=Positions(lineno=8, end_lineno=8, col_offset=8, end_col_offset=34))
Instruction(opname='IMPORT_NAME', opcode=108, arg=0, argval='builtins', argrepr='builtins', offset=24, starts_line=None, is_jump_target=False, positions=Positions(lineno=8, end_lineno=8, col_offset=8, end_col_offset=34))
Instruction(opname='IMPORT_FROM', opcode=109, arg=1, argval='print', argrepr='print', offset=26, starts_line=None, is_jump_target=False, positions=Positions(lineno=8, end_lineno=8, col_offset=8, end_col_offset=34))
Instruction(opname='STORE_FAST', opcode=125, arg=0, argval='print', argrepr='print', offset=28, starts_line=None, is_jump_target=False, positions=Positions(lineno=8, end_lineno=8, col_offset=8, end_col_offset=34))
Instruction(opname='POP_TOP', opcode=1, arg=None, argval=None, argrepr='', offset=30, starts_line=None, is_jump_target=False, positions=Positions(lineno=8, end_lineno=8, col_offset=8, end_col_offset=34))
Instruction(opname='PUSH_NULL', opcode=2, arg=None, argval=None, argrepr='', offset=32, starts_line=9, is_jump_target=False, positions=Positions(lineno=9, end_lineno=9, col_offset=8, end_col_offset=13))
Instruction(opname='LOAD_FAST', opcode=124, arg=0, argval='print', argrepr='print', offset=34, starts_line=None, is_jump_target=False, positions=Positions(lineno=9, end_lineno=9, col_offset=8, end_col_offset=13))
Instruction(opname='LOAD_DEREF', opcode=137, arg=3, argval='x', argrepr='x', offset=36, starts_line=None, is_jump_target=False, positions=Positions(lineno=9, end_lineno=9, col_offset=14, end_col_offset=15))
Instruction(opname='PRECALL', opcode=166, arg=1, argval=1, argrepr='', offset=38, starts_line=None, is_jump_target=False, positions=Positions(lineno=9, end_lineno=9, col_offset=8, end_col_offset=16))
Instruction(opname='CALL', opcode=171, arg=1, argval=1, argrepr='', offset=42, starts_line=None, is_jump_target=False, positions=Positions(lineno=9, end_lineno=9, col_offset=8, end_col_offset=16))
Instruction(opname='POP_TOP', opcode=1, arg=None, argval=None, argrepr='', offset=52, starts_line=None, is_jump_target=False, positions=Positions(lineno=9, end_lineno=9, col_offset=8, end_col_offset=16))
Instruction(opname='LOAD_CONST', opcode=100, arg=4, argval=77, argrepr='77', offset=54, starts_line=10, is_jump_target=False, positions=Positions(lineno=10, end_lineno=10, col_offset=28, end_col_offset=30))
Instruction(opname='LOAD_DEREF', opcode=137, arg=2, argval='other_thing', argrepr='other_thing', offset=56, starts_line=None, is_jump_target=False, positions=Positions(lineno=10, end_lineno=10, col_offset=8, end_col_offset=19))
Instruction(opname='LOAD_CONST', opcode=100, arg=5, argval='hi', argrepr="'hi'", offset=58, starts_line=None, is_jump_target=False, positions=Positions(lineno=10, end_lineno=10, col_offset=20, end_col_offset=24))
Instruction(opname='STORE_SUBSCR', opcode=60, arg=None, argval=None, argrepr='', offset=60, starts_line=None, is_jump_target=False, positions=Positions(lineno=10, end_lineno=10, col_offset=8, end_col_offset=25))
Instruction(opname='LOAD_CLOSURE', opcode=136, arg=2, argval='other_thing', argrepr='other_thing', offset=64, starts_line=12, is_jump_target=False, positions=Positions(lineno=12, end_lineno=14, col_offset=8, end_col_offset=21))
Instruction(opname='BUILD_TUPLE', opcode=102, arg=1, argval=1, argrepr='', offset=66, starts_line=None, is_jump_target=False, positions=Positions(lineno=12, end_lineno=14, col_offset=8, end_col_offset=21))
Instruction(opname='LOAD_CONST', opcode=100, arg=6, argval=<code object thingy at 0x1051e7500, file "<stdin>", line 12>, argrepr='<code object thingy at 0x1051e7500, file "<stdin>", line 12>', offset=68, starts_line=None, is_jump_target=False, positions=Positions(lineno=12, end_lineno=14, col_offset=8, end_col_offset=21))
Instruction(opname='MAKE_FUNCTION', opcode=132, arg=8, argval=8, argrepr='closure', offset=70, starts_line=None, is_jump_target=False, positions=Positions(lineno=12, end_lineno=14, col_offset=8, end_col_offset=21))
Instruction(opname='STORE_FAST', opcode=125, arg=1, argval='thingy', argrepr='thingy', offset=72, starts_line=None, is_jump_target=False, positions=Positions(lineno=12, end_lineno=14, col_offset=8, end_col_offset=21))
Instruction(opname='PUSH_NULL', opcode=2, arg=None, argval=None, argrepr='', offset=74, starts_line=15, is_jump_target=False, positions=Positions(lineno=15, end_lineno=15, col_offset=15, end_col_offset=21))
Instruction(opname='LOAD_FAST', opcode=124, arg=1, argval='thingy', argrepr='thingy', offset=76, starts_line=None, is_jump_target=False, positions=Positions(lineno=15, end_lineno=15, col_offset=15, end_col_offset=21))
Instruction(opname='PRECALL', opcode=166, arg=0, argval=0, argrepr='', offset=78, starts_line=None, is_jump_target=False, positions=Positions(lineno=15, end_lineno=15, col_offset=15, end_col_offset=23))
Instruction(opname='CALL', opcode=171, arg=0, argval=0, argrepr='', offset=82, starts_line=None, is_jump_target=False, positions=Positions(lineno=15, end_lineno=15, col_offset=15, end_col_offset=23))
Instruction(opname='RETURN_VALUE', opcode=83, arg=None, argval=None, argrepr='', offset=92, starts_line=None, is_jump_target=False, positions=Positions(lineno=15, end_lineno=15, col_offset=8, end_col_offset=23))



Instruction(opname='COPY_FREE_VARS', opcode=149, arg=1, argval=1, argrepr='', offset=0, starts_line=None, is_jump_target=False, positions=Positions(lineno=None, end_lineno=None, col_offset=None, end_col_offset=None))
Instruction(opname='MAKE_CELL', opcode=135, arg=2, argval='other_thing', argrepr='other_thing', offset=2, starts_line=None, is_jump_target=False, positions=Positions(lineno=None, end_lineno=None, col_offset=None, end_col_offset=None))
Instruction(opname='RESUME', opcode=151, arg=0, argval=0, argrepr='', offset=4, starts_line=4, is_jump_target=False, positions=Positions(lineno=4, end_lineno=4, col_offset=0, end_col_offset=0))
Instruction(opname='BUILD_MAP', opcode=105, arg=0, argval=0, argrepr='', offset=6, starts_line=5, is_jump_target=False, positions=Positions(lineno=5, end_lineno=5, col_offset=22, end_col_offset=24))
Instruction(opname='STORE_DEREF', opcode=138, arg=2, argval='other_thing', argrepr='other_thing', offset=8, starts_line=None, is_jump_target=False, positions=Positions(lineno=5, end_lineno=5, col_offset=8, end_col_offset=19))
Instruction(opname='LOAD_DEREF', opcode=137, arg=3, argval='x', argrepr='x', offset=10, starts_line=7, is_jump_target=False, positions=Positions(lineno=7, end_lineno=7, col_offset=8, end_col_offset=9))
Instruction(opname='LOAD_CONST', opcode=100, arg=1, argval=1, argrepr='1', offset=12, starts_line=None, is_jump_target=False, positions=Positions(lineno=7, end_lineno=7, col_offset=13, end_col_offset=14))
Instruction(opname='BINARY_OP', opcode=122, arg=13, argval=13, argrepr='+=', offset=14, starts_line=None, is_jump_target=False, positions=Positions(lineno=7, end_lineno=7, col_offset=8, end_col_offset=14))
Instruction(opname='STORE_DEREF', opcode=138, arg=3, argval='x', argrepr='x', offset=18, starts_line=None, is_jump_target=False, positions=Positions(lineno=7, end_lineno=7, col_offset=8, end_col_offset=9))
Instruction(opname='LOAD_CONST', opcode=100, arg=2, argval=0, argrepr='0', offset=20, starts_line=8, is_jump_target=False, positions=Positions(lineno=8, end_lineno=8, col_offset=8, end_col_offset=34))
Instruction(opname='LOAD_CONST', opcode=100, arg=3, argval=('print',), argrepr="('print',)", offset=22, starts_line=None, is_jump_target=False, positions=Positions(lineno=8, end_lineno=8, col_offset=8, end_col_offset=34))
Instruction(opname='IMPORT_NAME', opcode=108, arg=0, argval='builtins', argrepr='builtins', offset=24, starts_line=None, is_jump_target=False, positions=Positions(lineno=8, end_lineno=8, col_offset=8, end_col_offset=34))
Instruction(opname='IMPORT_FROM', opcode=109, arg=1, argval='print', argrepr='print', offset=26, starts_line=None, is_jump_target=False, positions=Positions(lineno=8, end_lineno=8, col_offset=8, end_col_offset=34))
Instruction(opname='STORE_FAST', opcode=125, arg=0, argval='print', argrepr='print', offset=28, starts_line=None, is_jump_target=False, positions=Positions(lineno=8, end_lineno=8, col_offset=8, end_col_offset=34))
Instruction(opname='POP_TOP', opcode=1, arg=None, argval=None, argrepr='', offset=30, starts_line=None, is_jump_target=False, positions=Positions(lineno=8, end_lineno=8, col_offset=8, end_col_offset=34))
Instruction(opname='PUSH_NULL', opcode=2, arg=None, argval=None, argrepr='', offset=32, starts_line=9, is_jump_target=False, positions=Positions(lineno=9, end_lineno=9, col_offset=8, end_col_offset=13))
Instruction(opname='LOAD_FAST', opcode=124, arg=0, argval='print', argrepr='print', offset=34, starts_line=None, is_jump_target=False, positions=Positions(lineno=9, end_lineno=9, col_offset=8, end_col_offset=13))
Instruction(opname='LOAD_DEREF', opcode=137, arg=3, argval='x', argrepr='x', offset=36, starts_line=None, is_jump_target=False, positions=Positions(lineno=9, end_lineno=9, col_offset=14, end_col_offset=15))
Instruction(opname='PRECALL', opcode=166, arg=1, argval=1, argrepr='', offset=38, starts_line=None, is_jump_target=False, positions=Positions(lineno=9, end_lineno=9, col_offset=8, end_col_offset=16))
Instruction(opname='CALL', opcode=171, arg=1, argval=1, argrepr='', offset=42, starts_line=None, is_jump_target=False, positions=Positions(lineno=9, end_lineno=9, col_offset=8, end_col_offset=16))
Instruction(opname='POP_TOP', opcode=1, arg=None, argval=None, argrepr='', offset=52, starts_line=None, is_jump_target=False, positions=Positions(lineno=9, end_lineno=9, col_offset=8, end_col_offset=16))
Instruction(opname='LOAD_CONST', opcode=100, arg=4, argval=77, argrepr='77', offset=54, starts_line=10, is_jump_target=False, positions=Positions(lineno=10, end_lineno=10, col_offset=28, end_col_offset=30))
Instruction(opname='LOAD_DEREF', opcode=137, arg=2, argval='other_thing', argrepr='other_thing', offset=56, starts_line=None, is_jump_target=False, positions=Positions(lineno=10, end_lineno=10, col_offset=8, end_col_offset=19))
Instruction(opname='LOAD_CONST', opcode=100, arg=5, argval='hi', argrepr="'hi'", offset=58, starts_line=None, is_jump_target=False, positions=Positions(lineno=10, end_lineno=10, col_offset=20, end_col_offset=24))
Instruction(opname='STORE_SUBSCR', opcode=60, arg=None, argval=None, argrepr='', offset=60, starts_line=None, is_jump_target=False, positions=Positions(lineno=10, end_lineno=10, col_offset=8, end_col_offset=25))
Instruction(opname='LOAD_CLOSURE', opcode=136, arg=2, argval='other_thing', argrepr='other_thing', offset=64, starts_line=12, is_jump_target=False, positions=Positions(lineno=12, end_lineno=14, col_offset=8, end_col_offset=21))
Instruction(opname='BUILD_TUPLE', opcode=102, arg=1, argval=1, argrepr='', offset=66, starts_line=None, is_jump_target=False, positions=Positions(lineno=12, end_lineno=14, col_offset=8, end_col_offset=21))
Instruction(opname='LOAD_CONST', opcode=100, arg=6, argval=<code object thingy at 0x1004c7500, file "<stdin>", line 12>, argrepr='<code object thingy at 0x1004c7500, file "<stdin>", line 12>', offset=68, starts_line=None, is_jump_target=False, positions=Positions(lineno=12, end_lineno=14, col_offset=8, end_col_offset=21))
Instruction(opname='MAKE_FUNCTION', opcode=132, arg=8, argval=8, argrepr='closure', offset=70, starts_line=None, is_jump_target=False, positions=Positions(lineno=12, end_lineno=14, col_offset=8, end_col_offset=21))
Instruction(opname='STORE_FAST', opcode=125, arg=1, argval='thingy', argrepr='thingy', offset=72, starts_line=None, is_jump_target=False, positions=Positions(lineno=12, end_lineno=14, col_offset=8, end_col_offset=21))
Instruction(opname='PUSH_NULL', opcode=2, arg=None, argval=None, argrepr='', offset=74, starts_line=15, is_jump_target=False, positions=Positions(lineno=15, end_lineno=15, col_offset=15, end_col_offset=21))
Instruction(opname='LOAD_FAST', opcode=124, arg=1, argval='thingy', argrepr='thingy', offset=76, starts_line=None, is_jump_target=False, positions=Positions(lineno=15, end_lineno=15, col_offset=15, end_col_offset=21))
Instruction(opname='PRECALL', opcode=166, arg=0, argval=0, argrepr='', offset=78, starts_line=None, is_jump_target=False, positions=Positions(lineno=15, end_lineno=15, col_offset=15, end_col_offset=23))
Instruction(opname='CALL', opcode=171, arg=0, argval=0, argrepr='', offset=82, starts_line=None, is_jump_target=False, positions=Positions(lineno=15, end_lineno=15, col_offset=15, end_col_offset=23))
Instruction(opname='RETURN_VALUE', opcode=83, arg=None, argval=None, argrepr='', offset=92, starts_line=None, is_jump_target=False, positions=Positions(lineno=15, end_lineno=15, col_offset=8, end_col_offset=23))